#!/usr/bin/env python
"""
Convert fastq file to fasta
"""

from vamp import __version__ as version

__author__ = "Lance Parsons"
__author_email__ = "lparsons@princeton.edu"
__copyright__ = "Copyright 2012, 2013, 2014 Lance Parsons"
__license__ = "BSD 2-Clause License http://opensource.org/licenses/BSD-2-Clause"

from Bio.SeqIO.QualityIO import FastqGeneralIterator
import argparse
import sys
import textwrap


def main(argv=None):
    if argv is None:
        argv = sys.argv

    parser = argparse.ArgumentParser(description=textwrap.dedent('''
       Convert a FASTQ file to a FASTA file'''))
    parser.add_argument('fastq_file')
    parser.add_argument('fasta_file')
    parser.add_argument('-w', '--wrap', type=int, default=0,
                        help='Maximum length of lines, 0 means do not wrap '
                        '(default: %(default)s)')
    parser.add_argument('-v', '--verbose', action='store_true',
                        default=False, help='verbose output')
    parser.add_argument('--version', action='version',
                        version='%(prog)s version ' + version)

    args = parser.parse_args(argv[1:])

    output_fh = open(args.fasta_file, 'wb')
    count = 0
    import fileinput
    fi = fileinput.FileInput(args.fastq_file,
                             openhook=fileinput.hook_compressed)
    for title, seq, qual in FastqGeneralIterator(fi):  # @UnusedVariable
        count += 1
        output_fh.write(">%s\n" % title)
        if args.wrap > 0:
            # Do line wrapping
            for i in range(0, len(seq), args.wrap):
                output_fh.write(seq[i:i + args.wrap] + "\n")
        else:
            output_fh.write("%s\n" % seq)
    if args.verbose:
        print 'Converted %s records' % count
    return 0


if __name__ == '__main__':
    sys.exit(main())
