#!/usr/bin/env python
"""
Extract fasta sequences from regions defined in GFF/BED file and output fasta
to stdout
"""

__author__ = "Lance Parsons"
__author_email__ = "lparsons@princeton.edu"
__copyright__ = ("Copyright 2012, 2014 Lance Parsons, "
                 "Lewis-Sigler Institute for Integrative Genomics, "
                 "Princeton University")
__license__ = ("BSD 2-Clause License "
               "http://www.opensource.org/licenses/BSD-2-Clause")

import optparse
import sys

import Bio.SeqIO
import pybedtools

from vamp import __version__ as version


def main(argv=None):
    if argv is None:
        argv = sys.argv

    usage = ("Usage: %prog [options] sequence_file (fasta/fastq) feature_file "
             "(gff/bed)")
    parser = optparse.OptionParser(
        usage=usage, version='%prog version %s' % version,
        description=globals()['__doc__'])
    parser.add_option('-v', '--verbose', action='store_true', default=False,
                      help='verbose output')
    parser.add_option('--sequenceformat', default='fasta',
                      help='Sequence file format (default: %default)')
    parser.add_option('--featureformat', default='gff',
                      help='Sequence feature file format (default: %default)')
    (options, args) = parser.parse_args(argv[1:])

    intervals = pybedtools.BedTool(args[1])
    seq_dict = Bio.SeqIO.index(args[0], options.sequenceformat)
    for interval in intervals:
        seq_record = seq_dict[interval.chrom]
        subseq = seq_record.seq[interval.start:interval.end]
        print('>%s\n%s\n' % (interval.name, subseq)),
    return 0


if __name__ == '__main__':
    sys.exit(main())
